# Adventlibs

This package contains some convenience functions for solving Advent of Code challenges. https://adventofcode.com.

NOTE: This package is in no way related to, endorsed by, or quite frankly, known by the creator of Advent of Code. 

